# daleydai

## karod bata road...

## Commands

### Fetch latest stock price and dump it to local file. Run it once a day to get latest data.

```bash
$ daleydai init
```

## Portfolio Commands

### Show my shares

```bash
$ daleydai show
```

### Add my shares

```bash
$ daleydai add <stock symbol>
```

### Remove from my shares

```bash
$ daleydai remove <stock_symbol>
```

## Broker Commands

Show bought or sold stocks by particular broker

```bash
$ daleydai buyer <broker_id>
```

```bash
$ daleydai seller <broker_id>
```
